@@ -47,14 +47,13 @@ public:
     void setText(const QString &label, const QString &text);
     void setHighLight(bool highlight);
 
-    virtual QSizeF sizeHint(Qt::SizeHint which, const QSizeF& constraint = QSizeF()) const;
-
 Q_SIGNALS:
     void pressed(bool);
     void clicked();
     void lookupTablePageUp();
     void lookupTablePageDown();
     void selectCandidate();
+    void sizeChanged();
 
 protected:
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
@@ -67,6 +66,7 @@ protected:
     virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
 private Q_SLOTS:
     void generatePixmap();
+    void updateSize();
 
 private:
     void hoverEffect(bool show);
