@@ -1,6 +1,7 @@
 /*
  *   Copyright 2008 Aaron Seigo <aseigo@kde.org>
  *   Copyright (C) 2009 Ryan P. Bitanga <ryan.bitanga@gmail.com>
+ *   Copyright 2012 Sebastian Kügler <sebas@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -21,6 +22,7 @@
 #ifndef TIMELINESOURCE_H
 #define TIMELINESOURCE_H
 
+#include "koauth.h"
 
 #include <KUrl>
 
@@ -29,7 +31,7 @@
 #include <Plasma/ServiceJob>
 
 // forward declarations
-class QXmlStreamReader;
+//class QXmlStreamReader;
 
 class KJob;
 
@@ -43,40 +45,9 @@ namespace QCA
     class Initializer;
 }
 
-class TimelineSource;
+class TimelineSourcePrivate;
 class ImageSource;
 
-class TweetJob : public Plasma::ServiceJob
-{
-    Q_OBJECT
-
-public:
-    TweetJob(TimelineSource *source, const QString &operation, const QMap<QString, QVariant> &parameters, QObject *parent = 0);
-    void start();
-
-private slots:
-    void result(KJob *job);
-
-private:
-    KUrl m_url;
-    QMap<QString, QVariant> m_parameters;
-    TimelineSource *m_source;
-};
-
-class TimelineService : public Plasma::Service
-{
-    Q_OBJECT
-
-public:
-    TimelineService(TimelineSource *parent);
-
-protected:
-    Plasma::ServiceJob* createJob(const QString &operation, QMap<QString, QVariant> &parameters);
-
-private:
-    TimelineSource *m_source;
-};
-
 class TimelineSource : public Plasma::DataContainer
 {
     Q_OBJECT
@@ -87,27 +58,43 @@ public:
         TimelineWithFriends,
         Replies,
         DirectMessages,
-        Profile
+        CustomTimeline,
+        SearchTimeline,
+        Profile,
+        User
     };
 
-    TimelineSource(const QString &who, RequestType requestType, QObject* parent);
+    TimelineSource(const QString &serviceUrl, RequestType requestType, KOAuth::KOAuth *oauthHelper, const QStringList &parameters, QObject* parent);
     ~TimelineSource();
 
-    void update(bool forcedUpdate = false);
     void setPassword(const QString &password);
     QString account() const;
     QString password() const;
     KUrl serviceBaseUrl() const;
+    bool needsAuthorization() const;
 
-    bool useOAuth() const;
     QByteArray oauthToken() const;
     QByteArray oauthTokenSecret() const;
+    void setOAuthHelper(KOAuth::KOAuth *authHelper);
+    KOAuth::KOAuth* oAuthHelper();
 
     Plasma::Service* createService();
+    void startAuthorization(const QString &user, const QString &password);
+    void forgetAccount(const QString &user, const QString &serviceUrl);
 
     ImageSource* imageSource() const;
     void setImageSource(ImageSource *);
 
+public Q_SLOTS:
+    KIO::Job* update(bool forcedUpdate = false);
+    KIO::Job* loadMore();
+
+Q_SIGNALS:
+    void authorize(const QString &serviceBaseUrl, const QString &user, const QString &password);
+    void userFound(const QVariant &userData, const QString &serviceBaseUrl);
+    void accountRemoved(const QString &account);
+    void userData(const QByteArray &data);
+
 private slots:
     void recv(KIO::Job*, const QByteArray& data);
     void result(KJob*);
@@ -116,24 +103,35 @@ private slots:
     void authFinished(KJob*);
 
 private:
-    void parse(QXmlStreamReader &xml);
-    void readStatus(QXmlStreamReader &xml);
-    void readUser(QXmlStreamReader &xml, const QString &tagName = "user");
-    void readDirectMessage(QXmlStreamReader &xml);
-    void skipTag(QXmlStreamReader &xml, const QString &tagName);
+//     void parse(QXmlStreamReader &xml);
+//     void readStatus(QXmlStreamReader &xml);
+//     void readUser(QXmlStreamReader &xml, const QString &tagName = "user");
+//     void readDirectMessage(QXmlStreamReader &xml);
+    void parseJson(const QByteArray &data);
+    void parseJsonUser(const QVariant &data);
+    void parseJsonSearchResult(const QByteArray &data);
+//     void parseSearchResult(QXmlStreamReader &xml);
+//     void readSearchStatus(QXmlStreamReader &xml);
+//     void skipTag(QXmlStreamReader &xml, const QString &tagName);
 
     // OAuth constants
     static const QString AccessTokenUrl;
 
+    TimelineSourcePrivate* d;
+
     KUrl m_url;
     KUrl m_serviceBaseUrl;
+    bool m_needsAuthorization;
+    RequestType m_requestType;
     ImageSource *m_imageSource;
     QByteArray m_xml;
     Plasma::DataEngine::Data m_tempData;
-    KIO::Job * m_job;
+    KIO::Job *m_job;
     QString m_id;
+    QOAuth::ParamMap m_params;
 
-    bool m_useOAuth;
+    KOAuth::KOAuth *m_authHelper;
+    QStringList m_parameters;
     QString m_user;
     QByteArray m_oauthTemp;
     KIO::Job *m_authJob;
